@@ -274,30 +274,31 @@ def mysql_proc(request):
     return mysql_executor
 
 
-def mysqldb_fixture(request, mysql_proc):
-    config = get_config(request)
+def mysqldb_fixture_factory(scope):
+    @pytest.fixture(scope)
+    def mysqldb_fixture(request, mysql_proc):
+        config = get_config(request)
 
-    MySQLdb, config = try_import(
-        'MySQLdb', request, pypi_package='MySQL-python'
-    )
+        MySQLdb, config = try_import(
+            'MySQLdb', request, pypi_package='MySQL-python'
+        )
 
-    mysql_conn = MySQLdb.connect(
-        host=config.mysql.host,
-        unix_socket=config.mysql.socket,
-        user=config.mysql.user,
-        passwd=config.mysql.password,
-    )
+        mysql_conn = MySQLdb.connect(
+            host=config.mysql.host,
+            unix_socket=config.mysql.socket,
+            user=config.mysql.user,
+            passwd=config.mysql.password,
+        )
 
-    mysql_conn.query('CREATE DATABASE %s' % config.mysql.db)
-    mysql_conn.query('USE %s' % config.mysql.db)
+        mysql_conn.query('CREATE DATABASE %s' % config.mysql.db)
+        mysql_conn.query('USE %s' % config.mysql.db)
 
-    def drop_database():
-        mysql_conn.query('DROP DATABASE IF EXISTS %s' % config.mysql.db)
-        mysql_conn.close()
+        def drop_database():
+            mysql_conn.query('DROP DATABASE IF EXISTS %s' % config.mysql.db)
+            mysql_conn.close()
 
-    request.addfinalizer(drop_database)
-    return mysql_conn
+        request.addfinalizer(drop_database)
+        return mysql_conn
 
-
-mysqldb_session = pytest.fixture(scope='session')(mysqldb_fixture)
-mysqldb = pytest.fixture(scope='function')(mysqldb_fixture)
+mysqldb_session = mysqldb_fixture_factory(scope='session')
+mysqldb = mysqldb_fixture_factory(scope='function')
